# Approach #1: Simple Constants
package_version = "0.1.0"
standard_grouping_for_aggregation = ["participant_id", "session_uuid", "session_id"]
standard_grouping_for_aggregation_metricwire = [
    "userId",
    "submissionSessionId",
    "activityId",
]
default_plot_color = "steelblue"
default_plot_dpi = 150
